@@ -16,12 +16,12 @@ be used for either standard or generalized eigenproblems, with real or
 complex arithmetic. It can also be used for computing a partial SVD of
 a large, sparse, rectangular matrix.
 
-.. _SLEPc: http://slepc.upv.es
-.. _PETSc: http://www.mcs.anl.gov/petsc
+.. _SLEPc: https://slepc.upv.es
+.. _PETSc: https://www.mcs.anl.gov/petsc
 """
 
 __author__    = 'Lisandro Dalcin'
-__version__   = '3.12.0'
+__version__   = '3.15.1'
 __credits__   = 'SLEPc Team <slepc-maint@upv.es>'
 
 # -----------------------------------------------------------------------------
